import unittest

from mothernature import Environment


class EnvironmentTest(unittest.TestCase):

    def setUp(self):
        self.config = Environment("env.yml")

    def test_environment_test(self):
        config = self.config.get_config("TEST")
        self.assertTrue(
            config.get("TESTING"),
            "TESTING should be True")

    def test_environment_dev(self):
        config = self.config.get_config("DEVELOPMENT")
        self.assertTrue(
            config.get("DEBUG"),
            "DEBUG should be True")

    def test_environment_stage(self):
        config = self.config.get_config("STAGING")
        self.assertTrue(
            config.get("DEBUG"),
            "DEBUG should be True")

    def test_environment_prod(self):
        config = self.config.get_config("PRODUCTION")
        self.assertTrue(
            config.get("IS_PRODUCTION"),
            "IS_PRODUCTION should be True")



import sys
import yaml


class Environment():

    def __init__(self, config_file, environment=None):
        self.environment = "COMMON"
        if environment:
            self.environment = environment
        else:
            if len(sys.argv) > 1:
                self.environment = sys.argv[1]
        with open(config_file, "r") as config:
            self.all_config = yaml.load(config)

    def get(self, key):
        env = self.get_config()
        return env.get(key)

    def get_config(self):
        env_data = self.all_config.get(self.environment)
        if self.environment == "COMMON" and not env_data:
            raise Exception(
                "You haven't specify COMMON configuration in your config file")

        if not env_data:
            raise Exception(
                "You have not specify this environment in your config file")

        return self._combine_env_data(env_data)

    def _combine_env_data(self, env_data):
        config = self.all_config.get("COMMON")
        if not config:
            return env_data

        for key, value in env_data.iteritems():
            config[key] = value
        return config

    def set_config(self, environment, key, value):
        self.all_config.get(environment)[key] = value
        return self.get_config(environment)



#!/usr/bin/env python

from setuptools import setup

setup(
    name='MotherNature',
    version='0.3',
    description='Python Environment Variables Manager',
    long_description="Manage python environment variables easier using yaml files instead of cluttering your run command.",
    author='Fauzan Emmerling',
    author_email='erich@emfeld.com',
    url='https://github.com/femmerling/mothernature',
    license='MIT',
    packages=['mothernature'],
    install_requires=['pyyaml'],
    zip_safe=False)
